<?php
/**
 * Register functions for Tutorly
 *
 * @author      VibeThemes
 * @category    Admin
 * @package     Register
 * @version     1.0
 */

if ( ! defined( 'ABSPATH' ) ) exit;


class Tutorly_Register{

    public static $instance;
    
    public static function init(){

        if ( is_null( self::$instance ) )
            self::$instance = new Tutorly_Register();

        return self::$instance;
    }

    private function __construct(){
        add_action('wp_enqueue_scripts',array($this,'enqueue_scripts'));
        add_action('admin_enqueue_scripts',array($this,'admin_enqueue_scripts'));
    	
    	add_action('widgets_init',array($this,'register_sidebars')); 
        add_action( 'customize_register', array($this,'logo_settings') );
        
        add_action( 'admin_init',array($this,'storegoogle_webfonts' ));

        add_action('in_widget_form',array($this,'widget_form'),10,3);
        add_filter('widget_update_callback', array($this,'save_widget_form'),10,3);
        add_filter('dynamic_sidebar_params',array($this,'footer_widgets'));
        
        add_action('woocommerce_before_main_content', array($this,'remove_sidebar' ));
        remove_action('woocommerce_after_shop_loop','woocommerce_pagination',10);
        add_action('woocommerce_after_shop_loop','vibe_pagination',10);
    }

    function remove_sidebar()
    {
        if( is_checkout() || is_cart() ) { 
         remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10);
       }
    }

    function admin_enqueue_scripts($hook){

        if($hook == 'nav-menus.php'){
            wp_enqueue_style( 'tutorly-menu-css', TUTORLY_URL .'/includes/menu/css/admin_menu.css' ,array(),TUTORLY_VERSION);
            wp_enqueue_script( 'tutorly-menu-js', TUTORLY_URL .'/includes/menu/js/admin_vibe_menu.js',array(),TUTORLY_VERSION);
        }
    }

    function enqueue_scripts(){
        wp_enqueue_style('vicons');
        if(empty(tutorly_get_option('default_font'))){
            wp_enqueue_style('default_fonts',TUTORLY_URL.'/css/default_fonts.css',array(),TUTORLY_VERSION);
        }

        if(empty(tutorly_get_option('theme_type'))){
            wp_dequeue_style( 'wp-block-library' );
            wp_dequeue_style( 'wp-block-library-theme' );
            wp_dequeue_style( 'wc-block-style' ); // REMOVE WOOCOMMERCE BLOCK CSS
            wp_dequeue_style( 'global-styles' ); // REMOVE THEME.JSON
        }
        
        $sections  = vibe_options_get_sections();


        $colors = wp_list_pluck($sections[4]['fields'],'id');

        $google_fonts = tutorly_get_option('google_fonts');
        if(!empty($google_fonts)){
            $font_string='';
            $font_weights = array();
            $font_subsets = array();
            foreach($google_fonts as $font){

              $font_var = explode('-',$font);

              if(!empty($font_weights[$font_var[0]]) && is_array($font_weights[$font_var[0]]) && isset($font_var[1])){
                if(!in_array($font_var[1],$font_weights[$font_var[0]]))
                  $font_weights[$font_var[0]][] = $font_var[1];
              }else{
                if(isset($font_var[1]))
                  $font_weights[$font_var[0]] = array($font_var[1]);
              }
              if(isset($font_var[2]))
              $font_subsets[] = $font_var[2];
            }

            if(!empty($font_weights)){
              foreach($font_weights as $font_name => $font_weight){
                $strings[$font_name] = implode(',',$font_weight);
              }
            }

            if(isset($strings) && is_array($strings)){
              foreach($strings as $key => $str){
                if($key){
                  $key = str_replace(' ','+',$key);
                  $font_string .= $key.':wght@'.$str.'|';
                }
              }
              $font_string = substr($font_string, 0, -1);
            }

            if(isset($font_subsets) && is_array($font_subsets)){
              $font_subsets = array_unique($font_subsets);
              if(!empty($font_subsets)){
                $font_string.='&subsets='.implode(',',$font_subsets);
              }  
            }
            
            if(!empty($font_string)){
              $query_args = apply_filters('vibe_font_query_args',array(
              'family' => $font_string,
              'display'=>'swap'
              ));

                echo '<link rel="preconnect" href="https://fonts.googleapis.com"><link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>';
              wp_enqueue_style('google-webfonts',
              esc_url(add_query_arg($query_args, "https://fonts.googleapis.com/css" )),
              array(), null);
            }
        }

        $custom_css='body,body.minimal{';
        foreach($colors as $color){
            if(strpos($color, '_dark') ==false){
            
                if(!empty(vibe_get_option($color))){
                    $custom_css .=' --'.$color.':'.vibe_get_option($color).';';
                }
                if($color == 'bg-primary'){
                    $custom_css .=' --primary:'.vibe_get_option($color).';';
                    $custom_css.='--swiper-theme-color:'.vibe_get_option($color).';';
                }
            }
        }
        
        $bg = vibe_get_option('header_background');
        if(empty($bg)){$bg = VIBE_URL.'/images/header_background.jpg';}

        $color = vibe_get_option('header_color');
        if(empty($color)){$color = '#fff';}


        if(wp_http_validate_url($bg)){
            $custom_css .='--header-bg:url('.$bg.') no-repeat;
            --header-color:'.$color.';';
        }else{
            $custom_css .='--header-bg:'.$bg.';
            --header-color:'.$color.';';
        }
        

        $font_family='Roboto Slab';

        $fonts = tutorly_get_option('google_fonts');

        $bf = tutorly_get_option('body-font');
        if(isset($bf) && !empty($fonts[$bf])){
             $custom_css .='--body-font:'.explode('-',$fonts[$bf])[0].';';
        }

        $hf=tutorly_get_option('heading-font');
        if(isset($hf) && !empty($fonts[$hf])){
             $custom_css .=' --heading-font:'.explode('-',$fonts[$hf])[0].';';
        }
        $custom_css .= '}';

        if(!empty(tutorly_get_option('dark_light_switcher'))){
        $custom_css .='body.dark_theme,body.minimal.dark_theme{';
            foreach($colors as $color){
                if(strpos($color, '_dark') !=false){
                    
                    if(!empty(vibe_get_option($color))){
                        $custom_css .=' --'.str_replace('_dark', '', $color).':'.vibe_get_option($color).';';
                    }

                    if($color == 'bg-primary'){
                        $custom_css .=' --primary:'.vibe_get_option($color).';';
                        $custom_css.='--swiper-theme-color:'.vibe_get_option($color).';';
                    }
                }
            }
            $custom_css .= '}';
        }


        wp_add_inline_style('tutorly',$custom_css);
    }


    function logo_settings( $wp_customize ) {
        $wp_customize->add_setting(
            'logo_width',
            array(
                'default' => '',
                'type' => 'theme_mod',
                'capability' => 'edit_theme_options',
                'transport' => 'postMessage', // or postMessage
                'sanitize_callback' => 'intval',
            )
        );

        $wp_customize->add_control(  'logo_width',array(
            'type'     => 'text',
            'section'  => 'title_tagline',
            'settings' => 'logo_width',
            'transport'=>'postMessage',
            'label'      => esc_html__( 'Logo Width', 'tutorly' ),
            'description' => esc_html__( 'Set a width to your logo [in Rem 4-20 recommended, number only]', 'tutorly' ),
            'sanitize_callback' => 'intval',
        ) ) ;
       

    }

  	function register_sidebars(){
      	if(function_exists('register_sidebar')){     
          	register_sidebar( array(
          		'name' => 'MainSidebar',
          		'id' => 'mainsidebar',
          		'before_widget' => '<div id="%1$s" class="widget %2$s">',
          		'after_widget' => '</div>',
          		'before_title' => '<h4 class="widget_title"><span>',
          		'after_title' => '</span></h4>',
              	'description'   => esc_html__('This is the global default widget area/sidebar for pages, posts, categories, tags and archive pages','tutorly')
    		) );

            if(function_exists('WC')){
                register_sidebar( array(
                    'name' => 'WooCommerce',
                    'id' => 'woocommerce',
                    'before_widget' => '<div id="%1$s" class="widget %2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h4 class="widget_title"><span>',
                    'after_title' => '</span></h4>',
                    'description'   => esc_html__('This is the Woocommerce widget area/sidebar for Shop, Products, categories, tags and archive pages','tutorly')
                ) );
            }

            if(!empty(tutorly_get_option('footer_sidebar'))){
                $columns = 3;
                if(!empty(vibe_get_option('footer_sidebar_colums'))){
                    $columns = vibe_get_option('footer_sidebar_colums');
                }
                register_sidebar( array(
                    'name' => 'Footer',
                    'id' => 'footer',
                    'before_widget' => '<div id="%1$s" class="widget flex-1 basis-1/'.$columns.' min-w-16 %2$s">',
                    'after_widget' => '</div>',
                    'before_title' => '<h3 class="widget_title"><span>',
                    'after_title' => '</span></h3>',
                    'description'   => esc_html__('This is footer widget area','tutorly')
                ) );
            }
      	}

        $sidebars=vibe_get_option('sidebars');
          if(isset($sidebars) && is_array($sidebars)){ 
              foreach($sidebars as $sidebar){ 
                  register_sidebar( array(
              'name' => $sidebar,
              'id' => $sidebar,
              'before_widget' => '<div class="widget"><div class="inside">',
              'after_widget' => '</div></div>',
              'before_title' => '<h4 class="widgettitle"><span>',
              'after_title' => '</span></h4>',
                  'description'   => esc_html__('Footer Manager','tutorly')
            ) );
            }
          }
    } 

     /*==== Reset Google Fonts ====*/
    function storegoogle_webfonts(){
        $google_webfonts=get_option('google_webfonts');
        if(!empty($google_webfonts)){
            
              if(!function_exists('WP_Filesystem')){
                require_once( ABSPATH . 'wp-admin/includes/file.php' );  
              }
              WP_Filesystem();
              global $wp_filesystem;
              $fonts = $wp_filesystem->get_contents(TUTORLY_PATH.'/js/fonts.json');
              add_option( 'google_webfonts', "$fonts",'', 'no');
            
        }
    } 

     function widget_form($widget, $return, $instance) {
        
        $columns = 0;
        if(isset($instance['tutorly_columns'])){$columns = $instance['tutorly_columns'];}
        ?>
        <p>
            <select class="tutorly_columns"  name="<?php echo esc_attr($widget->get_field_name('tutorly_columns')); ?>" id="<?php echo esc_attr($widget->get_field_name('tutorly_columns')); ?>">
                <option><?php esc_html_e('Set width column','tutorly') ?></option>
                <option value="2" <?php selected($columns,'2'); ?>><?php esc_html_e('2 column','tutorly') ?></option>
                <option value="3" <?php selected($columns,'3'); ?>><?php esc_html_e('3 column','tutorly') ?></option>
                <option value="4" <?php selected($columns,'4'); ?>><?php esc_html_e('4 column','tutorly') ?></option>
                <option value="5" <?php selected($columns,'5'); ?>><?php esc_html_e('5 column','tutorly') ?></option>
            </select>
            <label for="<?php echo esc_attr($widget->get_field_name('tutorly_columns')); ?>"><?php esc_html_e('Width Column', 'tutorly'); ?></label>
        </p>
        <?php
    }

    
    function save_widget_form($instance, $new_instance, $old_instance) {
        $instance['tutorly_columns'] = isset($new_instance['tutorly_columns'])?$new_instance['tutorly_columns']:0;
        return $instance;
    }

    function footer_widgets($params) {
        global $wp_registered_widgets;
        $widget_id        = $params[0]['widget_id'];
        $widget_obj       = $wp_registered_widgets[ $widget_id ];
        $widget_opt       = get_option( $widget_obj['callback'][0]->option_name );
        $widget_num       = $widget_obj['params'][0]['number'];
        $grid_class       = isset( $widget_opt[ $widget_num ]['tutorly_columns'] ) ? $widget_opt[ $widget_num ]['tutorly_columns'] : '';
 
        if ( preg_match( '/class="/', $params[0]['before_widget'] ) && $grid_class ) {
            $params[0]['before_widget'] = preg_replace( '/basis-1/', "basis-$grid_class", $params[0]['before_widget'], 1 );
            $params[0]['before_widget'] = preg_replace( '/widget/', "col-span-$grid_class widget", $params[0]['before_widget'], 1 );
            
        }
 
        return $params;
    }
}

Tutorly_Register::init();

