<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Tutorly_Admin_Welcome {

	private $plugin;
	public $major_version = TUTORLY_VERSION;
	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	public function __construct() {

		// Bail if user cannot moderate
		if ( ! current_user_can( 'manage_options' ) )
			return;
		add_action( 'admin_menu', array( $this, 'admin_menus') );
		// add_action( 'admin_head', array( $this, 'admin_head' ) );
		// add_action( 'admin_init', array( $this, 'welcome'    ) );
		//add_action('wp_ajax_tutorly_demo_data_download_install_activate_plugin',array($this,'tutorly_demo_data_download_install_activate_plugin'));

	}

	/**
	 * Add admin menus/screens
	 *
	 * @access public
	 * @return void
	 */
	public function admin_menus() {	

		
		$page = add_dashboard_page( esc_html__( 'Welcome to Tutorly', 'tutorly' ), esc_html__( 'About Tutorly', 'tutorly' ), 'manage_options', 'tutorly-about', array( $this, 'about_screen' ) );
		add_action( 'admin_print_styles-'. $page, array( $this, 'admin_css' ) );
			
	}

	/**
	 * admin_css function.
	 *
	 * @access public
	 * @return void
	 */
	public function admin_css() {
		wp_enqueue_style( 'tutorly-intro-font',"https://fonts.googleapis.com/css2?family=Mulish:wght@200;300;400;700;900&display=swap" );
		wp_enqueue_style( 'vibe-activation', TUTORLY_URL.'/setup/installer/css/envato-setup.css',array(),TUTORLY_VERSION);
	}

	/**
	 * Add styles just for this page, and remove dashboard page links.
	 *
	 * @access public
	 * @return void
	 */
	public function admin_head() {
		if(isset($_REQUEST['page']) && $_REQUEST['page'] == 'tutorly-about'){
			remove_submenu_page( 'index.php', 'tutorly-about' );		
		}

		?>
		<style type="text/css">
			/*<![CDATA[*/
			.tutorly-wrap .tutorly-badge {
				<?php echo is_rtl() ? 'left' : 'right'; ?>: 0;
			}
			.tutorly-wrap .feature-rest div {
				float:<?php echo is_rtl() ? 'right':'left' ; ?>;
			}
			.tutorly-wrap .feature-rest div.last-feature {
				padding-<?php echo is_rtl() ? 'right' : 'left'; ?>: 50px !important;
				padding-<?php echo is_rtl() ? 'left' : 'right'; ?>: 0;
			}
			.three-col > div{
				float:<?php echo is_rtl() ? 'right':'left' ; ?>;
			}
			/*]]>*/
		</style>
		<?php
	}

	/**
	 * Into text/links shown on all about pages.
	 *
	 * @access private
	 * @return void
	 */
	private function intro() {

		// Flush after upgrades
		if ( ! empty( $_GET['tutorly-updated'] ) || ! empty( $_GET['tutorly-installed'] ) )
			flush_rewrite_rules();
		?>
		<h1><?php printf( esc_html__( 'Tutorly %s', 'tutorly' ), $this->major_version ); ?></h1>

		<?php 

		
		$this->purchase_code = get_option('item_purchase_code');

		if(empty($this->purchase_code)){
			?>
				<a href="<?php echo admin_url('/themes.php?page=tutorly-setup&setup=updaed&referrer=about&step=updates'); ?>" class="important_notice"> <?php wp_nonce_field(); ?>
					Plugin auto-updates not configured. Click here to Setup Plugin auto-updates.
				</a>

			<?php
		}
		?>
		

		<div class="about-text tutorly-about-text">
			Thank you for installing <strong>Tutorly Theme</strong>. This is the about page for Tutorly.
		</div>
		<a href="https://tutorlydocs.wpappointify.com" target="_blank">Latest Documentation ›</a>
		<br><br>
		<?php
	}

	
	
	/**
	 * Output the about screen.
	 */
	public function about_screen() {
		?>
		<div class="setup_wizard_wrapper_wrapper">
		<div class="setup_wizard_wrapper">
			<div class="onboarding introduction">
				<div class="onboarding_header">
					<span><img id="tutorly_logo" class="site-logo" src="http://localhost/tutorly/wp-content/themes/tutorly/images/logo.png" alt="tutorly" width="120">
						<span>Tutor Booking System</span>
					</span>
					
				</div>
				<div class="onboarding_introduction">
					<h2>Introduction.</h2>
					<span><a>2 years</a>. Inbuilt App platform. Commissions.</span>
				</div>
				<a href="https://tutorlydocs.wpappointify.com/about/update-log" target="_blank">View full update log ›</a>
			</div>
			<div class="setup_wizard_main">
				<div class="setup_wizard_main_header">
					<span></span>
					<span>Having Troubles ? <a href="https://wpappointify.com/tutorly/app/">Get Help</a></span>
				</div>
				<div class="envato-setup-content">				
					<?php $this->intro(); ?>

				<div class="tutorly_about_tabs">
					
					<input type="radio" id="tutorly_whats_new" name="tutorly_about_active_tab" checked />
					<label for="tutorly_whats_new">Whats New</label>
					

					<input type="radio" id="tutorly_support" name="tutorly_about_active_tab" />
					<label for="tutorly_support">Support</label>
					
					<input type="radio" id="tutorly_system_status" name="tutorly_about_active_tab"  />
					<label for="tutorly_system_status">System Status</label>
					
					<input type="radio" id="tutorly_changelog" name="tutorly_about_active_tab" />
					<label for="tutorly_changelog">Changelog</label>
					<hr>
					<div class="tutorly_about_tab tutorly_whats_new"> 
						<?php 
						$this->welcome_screen();
						?>
					</div>
					<div class="tutorly_about_tab tutorly_support"> 
						<?php 
						$this->support_screen();
						?>
					</div>
					<div class="tutorly_about_tab tutorly_system_status"> 
						<?php 
						$this->system_screen();
						?>
					</div>
					<div class="tutorly_about_tab tutorly_changelog"> 
						<?php 
						$this->changelog_screen();
						?>
					</div>
				</div>
				<p class="envato-setup-actions step">
					<div class="return-to-dashboard">
					<a href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'tutorly_options' ), 'admin.php' ) ) ); ?>"><?php esc_html_e( 'Go to Tutorly Options panel', 'tutorly' ); ?></a>

					</div>
				</p>
				</div>
				

			</div>
			
		</div>	
		</div>
		<?php
	}

	public function welcome_screen(){
		?>
		<div class="welcome_slider">
  
		  	<div class="slides">
		  		<div id="slide-1">
		    		<img src="<?php echo VIBE_URL.'/setup/installer/images/1.png'; ?>" alt="base demo" />
			    </div>
			    
			    <div id="slide-2">
		    		<img src="<?php echo VIBE_URL.'/setup/installer/images/2.png'; ?>" />
			    </div>
			    
		  	</div>
		  	<div class="slider_dots">
		  		<a href="#slide-1"></a>
		  		<a href="#slide-2"></a>
			</div>
		</div>
		<?php
	}

	public function support_screen(){
		?>
		<div class="tutorly_support_wrapper">
			<a href="https://facebook.com/vibethemes">Get Live Support. Just drop a message.</a>
			<a href="https://vibethmes.ticksy.com/">Create a Ticket</a>
		</div>
		<?php
	}

	public function system_screen(){
		?>
		<table class="tutorly_status_table widefat" cellspacing="0" id="status">
				<thead>
					<tr>
						<th colspan="2"><h4><?php esc_html_e( 'Environment', 'tutorly' ); ?></h4></th>
					</tr>
				</thead>

				<tbody>
					<tr>
						<td><?php esc_html_e( 'Home URL', 'tutorly' ); ?>:</td>
						<td><?php echo home_url(); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'Site URL', 'tutorly' ); ?>:</td>
						<td><?php echo site_url(); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Version', 'tutorly' ); ?>:</td>
						<td><?php bloginfo('version'); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Multisite Enabled', 'tutorly' ); ?>:</td>
						<td><?php if ( is_multisite() ) echo esc_html__( 'Yes', 'tutorly' ); else echo esc_html__( 'No', 'tutorly' ); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'PHP Version', 'tutorly' ); ?>:</td>
						<td><?php if ( function_exists( 'phpversion' ) ) echo esc_html( phpversion() ); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'MySQL Version', 'tutorly' ); ?>:</td>
						<td>
							<?php
							/** @global wpdb $wpdb */
							global $wpdb;
							echo esc_attr($wpdb->db_version());
							?>
						</td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Active Plugins', 'tutorly' ); ?>:</td>
						<td><?php echo count( (array) get_option( 'active_plugins' ) ); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Memory Limit', 'tutorly' ); ?>:</td>
						<td><?php
							$memory = $this->tutorly_let_to_num( WP_MEMORY_LIMIT );
							if ( $memory < 134217728 ) {
								echo '<mark class="error">' . sprintf( esc_html__( '%s - We recommend setting memory to at least 128MB. See: <a href="%s">Increasing memory allocated to PHP</a>', 'tutorly' ), size_format( $memory ), 'http://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP' ) . '</mark>';
							} else {
								echo '<mark class="yes">' . size_format( $memory ) . '</mark>';
							}
						?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Debug Mode', 'tutorly' ); ?>:</td>
						<td><?php if ( defined('WP_DEBUG') && WP_DEBUG ) echo '<mark class="no">' . esc_html__( 'Yes', 'tutorly' ) . '</mark>'; else echo '<mark class="yes">' . esc_html__( 'No', 'tutorly' ) . '</mark>'; ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Language', 'tutorly' ); ?>:</td>
						<td><?php echo get_locale(); ?></td>
					</tr>
					<tr>
						<td><?php esc_html_e( 'WP Max Upload Size', 'tutorly' ); ?>:</td>
						<td><?php echo size_format( wp_max_upload_size() ); ?></td>
					</tr>
					<?php if ( function_exists( 'ini_get' ) ) : ?>
						<tr>
							<td><?php esc_html_e('PHP Post Max Size', 'tutorly' ); ?>:</td>
							<td><?php echo size_format($this->tutorly_let_to_num( ini_get('post_max_size') ) ); ?></td>
						</tr>
						<tr>
							<td><?php esc_html_e('PHP Time Limit', 'tutorly' ); ?>:</td>
							<td><?php echo ini_get('max_execution_time'); ?></td>
						</tr>
						<tr>
							<td><?php esc_html_e( 'PHP Max Input Vars', 'tutorly' ); ?>:</td>
							<td><?php echo ini_get('max_input_vars'); ?></td>
						</tr>
					<?php endif; ?>
					<tr>
						<td><?php esc_html_e( 'Default Timezone', 'tutorly' ); ?>:</td>
						<td><?php
							$default_timezone = date_default_timezone_get();
							if ( 'UTC' !== $default_timezone ) {
								echo '<mark class="error">' . sprintf( esc_html__( 'Default timezone is %s - it should be UTC', 'tutorly' ), $default_timezone ) . '</mark>';
							} else {
								echo '<mark class="yes">' . sprintf( esc_html__( 'Default timezone is %s', 'tutorly' ), $default_timezone ) . '</mark>';
							} ?>
						</td>
					</tr>
				</tbody>


			</table>
		<?php
	}

	/**
	 * Output the changelog screen
	 */
	public function changelog_screen() {
		?>
		<div class="wrap tutorly-wrap about-wrap">

			
			<div class="changelog-description">
			<p><?php printf( esc_html__( 'Full Changelog of Tutorly Theme', 'tutorly' ), 'tutorly' ); ?></p>

			<?php
				if(function_exists('WP_Filesystem')){
					WP_Filesystem();
					global $wp_filesystem;
					$file = VIBE_URL.'/changelog.txt';
					$content = $wp_filesystem->get_contents( $file );

					print_r($content);	
				}
				
			?>
			</div>
		</div>
		<?php
	}
	
	/**
	 * Sends user to the welcome page on first activation
	 */
	public function welcome() {
		//Bail if no activation redirect transient is set
	    if ( ! get_transient( '_tutorly_activation_redirect' ) ) {
			return;
	    }

		
		// Bail if activating from network, or bulk, or within an iFrame
		if ( is_network_admin() || defined( 'IFRAME_REQUEST' ) ) {
			return;
		}

		if(!$this->check_installed()){
			if(empty($_GET['page']) || $_GET['page'] != 'tutorly-setup'){
				wp_redirect( admin_url( 'themes.php?page=tutorly-setup' ) );
			}
		}else{
			if(empty($_GET['page']) || $_GET['page'] != 'tutorly-about'){
				wp_redirect( admin_url( 'index].php?page=tutorly-about' ) );
			}
		}

		wp_redirect( admin_url( 'index.php?page=tutorly-about' ) );
		exit;
	}
	function tutorly_let_to_num( $size ) {
		$l   = substr( $size, -1 );
		$ret = substr( $size, 0, -1 );
		switch ( strtoupper( $l ) ) {
			case 'P':
				$ret *= 1024;
			case 'T':
				$ret *= 1024;
			case 'G':
				$ret *= 1024;
			case 'M':
				$ret *= 1024;
			case 'K':
				$ret *= 1024;
		}
		return $ret;
	}
	function check_installed(){
		//No plugin dependency to check Installed
		return true;
	}
}

add_action('init','tutorly_welcome_user');
function tutorly_welcome_user(){
	new Tutorly_Admin_Welcome();	
}
