<?php
if ( ! defined( 'ABSPATH' ) ) exit;
if(!class_exists('Vibe_Options')){
	require_once( dirname( __FILE__ ) . '/options/options.php' );
}
/*
 * 
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){
	
	//$sections = array();
	$sections[] = array(
				'title' => esc_html__('A Section added by hook', 'tutorly'),
				'desc' => '<p class="description">'.esc_html__('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'tutorly').'</p>',
				//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
				//You dont have to though, leave it blank for default.
				'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
				//Lets leave this as a blank section, no options just some intro text set above.
				'fields' => array()
				);
	
	return $sections;
	
}//function


/*
 * 
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){
	
	//$args['dev_mode'] = false;
	
	return $args;
	
}


function vibe_options_get_sections(){
	$sections = array();

	$sections[] = array(
					'title' => esc_html__('Theme', 'tutorly'),
					'desc' => '<p class="description">'.sprintf(__('Welcome to %s Theme Options panel. ','tutorly'),THEME_FULL_NAME).'</p>',
					'icon' => 'menu',
	                'fields' => array(
	                        array(
								'id' => 'theme_type',
								'type' => 'button_set',
								'title' => esc_html__('Theme Type', 'tutorly'), 
								'sub_desc' => esc_html__('Switch between theme type' , 'tutorly'),
								'desc' => esc_html__('FSE Theme vs Regular WP Theme.', 'tutorly'),
								'options' => array('0' => esc_html__('Elementor','tutorly'),'1' => esc_html__('FSE Theme','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							), 
							array(
								'id' => 'theme_skin',
								'type' => 'button_set',
								'title' => esc_html__('Theme Skin', 'tutorly'), 
								'sub_desc' => esc_html__('set a theme skin' , 'tutorly'),
								'desc' => esc_html__('FSE Theme vs Regular WP Theme.', 'tutorly'),
								'options' => array('0' => esc_html__('Default skin','tutorly'),'minimal' => esc_html__('Minimal skin','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),
							array(
								'id' => 'dark_light_switcher',
								'type' => 'button_set',
								'title' => esc_html__('Dark Light Switch', 'tutorly'), 
								'sub_desc' => esc_html__('enable a dark/ light switch' , 'tutorly'),
								'desc' => esc_html__('Dark to Light Theme switcher.', 'tutorly'),
								'options' => array('0' => esc_html__('No','tutorly'),'1' => esc_html__('Yes','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							), 
							array(
								'id' => 'default_dark_theme',
								'type' => 'button_set',
								'title' => esc_html__('Default Dark Theme', 'tutorly'), 
								'sub_desc' => esc_html__('Set default Dark colors' , 'tutorly'),
								'desc' => esc_html__('Default Dark theme. Set colors in the Colors section.', 'tutorly'),
								'options' => array('0' => esc_html__('No','tutorly'),'minimal' => esc_html__('Yes','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),  
	                    )
	            	);


	$sections[] = array(
					'icon' => 'admin-generic',
					'title' => esc_html__('Header', 'tutorly'),
					'desc' => '<p class="description">'.esc_html__('Header settings','tutorly').'..</p>',
					'fields' => array(
	                        array(
								'id' => 'header_fix',
								'type' => 'button_set',
								'title' => esc_html__('Fix Top Header on Scroll', 'tutorly'), 
								'sub_desc' => esc_html__('Fix header on top of screen' , 'tutorly'),
								'desc' => esc_html__('header is fixed to top as user scrolls down.', 'tutorly'),
								'options' => array('0' => esc_html__('Static','tutorly'),'1' => esc_html__('Fixed on Scroll','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),  
							array(
								'id' => 'header_search',
								'type' => 'button_set',
								'title' => esc_html__('Show Search in Site Header', 'tutorly'), 
								'sub_desc' => esc_html__('Search bar appears in the header.' , 'tutorly'),
								'desc' => esc_html__('Show an expanded search bar in the header', 'tutorly'),
								'options' => array('0' => esc_html__('Disable','tutorly'),'1' => esc_html__('Enable','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),
							array(
								'id' => 'wide_header',
								'type' => 'button_set',
								'title' => esc_html__('Fullwidth Header' ,'tutorly'), 
								'sub_desc' => esc_html__('Default Wide header' , 'tutorly'),
								'desc' => esc_html__('Set a screen wide header.', 'tutorly'),
								'options' => array('0' => esc_html__('Disable','tutorly'),'1' => esc_html__('Enable','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),
							
							array(
								'id' => 'mega_menus',
								'type' => 'button_set',
								'title' => esc_html__('Enable MegaMenu', 'tutorly'), 
								'sub_desc' => esc_html__('Mega menus by default. Changes presentation of default menus.' , 'tutorly'),
								'desc' => esc_html__('Mega menu presentation is changed.', 'tutorly'),
								'options' => array('0' => esc_html__('Disable','tutorly'),'1' => esc_html__('Enable','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),  
							array(
								'id' => 'header_background',
								'type' => 'text_upload',
								'title' => esc_html__('Header Background', 'tutorly'), 
								'sub_desc' => esc_html__('Header background', 'tutorly'),
								'desc' => esc_html__('Set a header background', 'tutorly'),
		                        'std' => VIBE_URL.'/images/header_background.jpg'
							),  
							array(
								'id' => 'header_color',
								'type' => 'color',
								'title' => esc_html__('Header Text color', 'tutorly'), 
								'sub_desc' => esc_html__('Color of Text in header', 'tutorly'),
								'desc' => esc_html__('Heading , breadcrumbs and other text color appearing on background', 'tutorly'),
		                        'std' => '#ffffff'
							), 
							array(
								'id' => 'header_extras',
								'type' => 'button_set',
								'title' => esc_html__('Show Login / Cart in Header', 'tutorly'), 
								'sub_desc' => esc_html__('Login link and cart appears in header.' , 'tutorly'),
								'desc' => esc_html__('Cart only appears when WooCommerce installed.', 'tutorly'),
								'options' => array('0' => esc_html__('Disable','tutorly'),'1' => esc_html__('Enable','tutorly')),//Must provide key => value pairs for radio options
							'std' => '0'
							),
							
						)
					);


	$sections[] = array(
					'icon' => 'groups',
					'title' => esc_html__('Buddypress', 'tutorly'),
					'desc' => '<p class="description">'.esc_html__('BuddyPress settings and Variables','tutorly').'..</p>',
					'fields' => array(
						array(
							'id' => 'default_avatar',
							'type' => 'upload',
							'title' => esc_html__('Upload BuddyPress default member avatar', 'tutorly'), 
							'sub_desc' => esc_html__('BuddyPress default members avatar', 'tutorly'),
							'desc' => '',
	                        'std' => VIBE_URL.'/assets/images/avatar.jpg'
							),
						array(
							'id' => 'wp_admin_access',
	                        'title' => esc_html__('WP Admin area access', 'tutorly'),
	                        'sub_desc' => esc_html__('Restrict WP Admin area access', 'tutorly'),
	                        'desc' => esc_html__('WP Admin area is restricted for', 'tutorly'),
	                        'type' => 'button_set',
							'options' => array('' => esc_html__('All','tutorly'),'1'=>esc_html__('Instructors & Administrators only','tutorly'),'2'=>esc_html__('Administrators only','tutorly')),
							'std' => ''
							),
						array(
							'id' => 'blog_create',
	                        'title' => esc_html__('Create Blog (multisite)', 'tutorly'),
	                        'sub_desc' => esc_html__('Blogs can be created by :', 'tutorly'),
	                        'desc' => sprintf(__('Blog creation : Members{Loggedin Members},Teachers {Teachers, Admins,Editors}, %s screenshot %s', 'tutorly'),'<a href="http://prntscr.com/cldri1" target="_blank">','</a>'),
	                        'type' => 'button_set',
							'options' => array('1'=>esc_html__('Members only','tutorly'),'2' => esc_html__('Teachers only','tutorly'),'3' => esc_html__('Admins only','tutorly')),//Must provide key => value pairs for radio options
							'std' => '1'
							),
						array(
							'id' => 'activation_redirect',
							'type' => 'pages_select',
							'options'=> array('dashboard'=>__('Dashboard','tutorly'),'profile'=>__('Profile','tutorly'),'dashboard'=>__('Dashboard','tutorly')),
	                        'title' => __('Redirect Page on User Activation', 'tutorly'),
	                        'sub_desc' => __('User is redirected to this page on activating her account.', 'tutorly'),
	                        'desc' => __('After registering and activating the account the user is redirected to this page.','tutorly')
							),
						array(
							'id' => 'instructor_paypal_field',
	                        'title' => esc_html__('Paypal field for Instructor payouts', 'tutorly'),
	                        'sub_desc' => esc_html__('Enter the exact name of the field', 'tutorly'),
	                        'desc' =>'',
	                        'type' => 'text',
							'std' => ''
							),
						array(
							'id' => 'custom_registration_page',
							'type' => 'pages_select',
	                        'title' => __('Custom Registration page', 'tutorly'),
	                        'sub_desc' => __('Overrides the default registration page from buddypress', 'tutorly'),
							),	
						
					)
				);

	$font_fields = [
		array(
			'id' => 'default_font',
            'title' => esc_html__('Disable Default font Roboto Slab', 'tutorly'),
            'sub_desc' => esc_html__('default font in Theme', 'tutorly'),
            'desc' => esc_html__('Since Google fonts store data, we have included a default font in the theme.', 'tutorly'),
            'type' => 'button_set',
			'options' => array(''=>esc_html__('No','tutorly'),'1' => esc_html__('Yes','tutorly')),//Must provide key => value pairs for radio options
			'std' => ''
		),
		array(
			'id' => 'google_fonts',
			'type' => 'google_webfonts_multi_select',
            'title' => esc_html__('Select Fonts for Live Theme Editor ', 'tutorly'),
            'sub_desc' => esc_html__('Select Fonts and setup fonts in Live Editor', 'tutorly'),
            'desc' => esc_html__('Use these sample layouts in PageBuilder.', 'tutorly')
		),
        array(
			'id' => 'custom_fonts',
			'type' => 'multi_text',
	        'title' => esc_html__('Custom Fonts (Enter CSS Font Family name)', 'tutorly'),
	        'sub_desc' => esc_html__(' Custom Fonts are added to Theme Customizer Font List.. ', 'tutorly')
		)
	];

	$fontlist = [];
	$saved_fonts = tutorly_get_option('google_fonts');
	if(!empty($saved_fonts) && is_array($saved_fonts)){
		$fontlist = array_merge($fontlist,$saved_fonts);
	}

	if(!empty(tutorly_get_option('custom_fonts'))){
		$fontlist = array_merge($fontlist,tutorly_get_option('google_fonts'));
	}
	if(!empty($fontlist)){
		$font_fields[]=[
			'id' => 'heading-font',
            'title' => esc_html__('Heading Font', 'tutorly'),
            'sub_desc' => esc_html__('Font for all Headings in Theme', 'tutorly'),
            'desc' => esc_html__('Select a fonts for the Headings', 'tutorly'),
            'type' => 'select',
			'options' => $fontlist,
			'std' => ''
		];
		$font_fields[]=[
			'id' => 'body-font',
            'title' => esc_html__('Body Font', 'tutorly'),
            'sub_desc' => esc_html__('Font for all elements in Theme', 'tutorly'),
            'desc' => esc_html__('Select a fonts for the Body', 'tutorly'),
            'type' => 'select',
			'options' => $fontlist,
			'std' => ''
		];
	}
	$sections[] = array(
					'icon' => 'editor-spellcheck',
					'title' => esc_html__('Fonts Manager', 'tutorly'),
					'desc' => '<p class="description">'.esc_html__('Manage Fonts to be used in the Site. Fonts selected here will be available in Theme customizer font family select options.','tutorly').'..</p>',
					'fields' => $font_fields
					);

	$colors = [
		array(
			'id' => 'bg-primary',
            'title' => esc_html__('Theme Primary color', 'tutorly'),
            'sub_desc' => esc_html__('Primary color in Theme', 'tutorly'),
            'desc' => esc_html__('Button background, link colors, hover colors.', 'tutorly'),
            'type' => 'color',
			'std' => ''
		),
		array(
			'id' => 'color-primary',
			'type' => 'color',
            'title' => esc_html__('Text color on Primary Background', 'tutorly'),
            'sub_desc' => esc_html__('Color of text on primary bg', 'tutorly'),
            'desc' => esc_html__('Primary Button background has this text color.', 'tutorly'),
            'std' => ''
		),

		array(
			'id' => 'header-background-color',
			'type' => 'color',
            'title' => esc_html__('Header Background', 'tutorly'),
            'sub_desc' => esc_html__(' Background of header area ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'root-menu-main-color',
			'type' => 'color',
            'title' => esc_html__('Header Text Color', 'tutorly'),
            'sub_desc' => esc_html__(' Text color of header area ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'root-menu-main-active-color',
			'type' => 'color',
            'title' => esc_html__('Active menu item', 'tutorly'),
            'sub_desc' => esc_html__('Text color of active menu item', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'sub-menu-hover-color',
			'type' => 'color',
            'title' => esc_html__('Active Sub menu item color', 'tutorly'),
            'sub_desc' => esc_html__('Text color of active sub-menu item', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'sub-menu-background-color',
			'type' => 'color',
            'title' => esc_html__('Background Sub menu color', 'tutorly'),
            'sub_desc' => esc_html__('Background color of sub-menu  & Mega menu', 'tutorly'),
            'std' => ''
		),
		
		
		array(
			'id' => 'header-color',
			'type' => 'color',
            'title' => esc_html__('Header Text color', 'tutorly'),
            'sub_desc' => esc_html__('Color of text on Header background ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'bodybg',
			'type' => 'color',
            'title' => esc_html__('Body Background', 'tutorly'),
            'sub_desc' => esc_html__('Background of body. ', 'tutorly'),
            'std' => ''
		),
        array(
			'id' => 'contentbg',
			'type' => 'color',
            'title' => esc_html__('Content Background', 'tutorly'),
            'sub_desc' => esc_html__(' Background of content area ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'text-color',
			'type' => 'color',
            'title' => esc_html__('Text Color', 'tutorly'),
            'sub_desc' => esc_html__(' default Text area ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'light-color',
			'type' => 'color',
            'title' => esc_html__('Light color', 'tutorly'),
            'sub_desc' => esc_html__('Slightly darker shade than content / body used in comments area background, products and more ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'highlight-color',
			'type' => 'color',
            'title' => esc_html__('Highlight color', 'tutorly'),
            'sub_desc' => esc_html__('Color of text on Header background ', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'highlight-bg',
			'type' => 'color',
            'title' => esc_html__('Highlight Background', 'tutorly'),
            'sub_desc' => esc_html__('Background color of highlighted area', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'post-content-border',
			'type' => 'color',
            'title' => esc_html__('Border Color', 'tutorly'),
            'sub_desc' => esc_html__('Border color', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'footer-bg',
			'type' => 'color',
            'title' => esc_html__('Footer background Color', 'tutorly'),
            'sub_desc' => esc_html__('Background color in footer', 'tutorly'),
            'std' => ''
		),
		array(
			'id' => 'footer-color',
			'type' => 'color',
            'title' => esc_html__('Footer Textarea Color', 'tutorly'),
            'sub_desc' => esc_html__('Text color in footer', 'tutorly'),
            'std' => ''
		),
	];

	if(!empty(tutorly_get_option('dark_light_switcher'))){
		foreach($colors as $k=>$color){
			$dark_color = $color;
			$dark_color['id']=$dark_color['id'].'_dark';
			$dark_color['title']=esc_html__('Dark','tutorly').' '.$dark_color['title'];
			$dark_color['sub_desc']=esc_html__('Dark','tutorly').' '.$dark_color['sub_desc'];
			$colors[]=$dark_color;
		}
	}
	
	$sections[] = array(
					'icon' => 'editor-spellcheck',
					'title' => esc_html__('Color Manager', 'tutorly'),
					'desc' => '<p class="description">'.esc_html__('Manage Colors used in the Site.','tutorly').'..</p>',
					'fields' => $colors
				);
	

$sections[] = array(
				'icon' => 'feedback',
				'title' => esc_html__('Sidebar Manager', 'tutorly'),
				'desc' => '<p class="description">'.esc_html__('Generate more sidebars dynamically and use them in various layouts','tutorly').'..</p>',
				'fields' => array(
					 array(
						'id' => 'sidebars',
						'type' => 'multi_text',
                        'title' => esc_html__('Create New sidebars ', 'tutorly'),
                        'sub_desc' => esc_html__('Dynamically generate sidebars', 'tutorly'),
                        'desc' => esc_html__('Use these sidebars in various layouts. DO NOT ADD ANY SPECIAL CHARACTERS in Sidebar name', 'tutorly')
						),		
					)
				);

	$sections[] = array(
					'icon' => 'editor-insertmore',
					'title' => esc_html__('Footer ', 'tutorly'),
					'desc' => '<p class="description">'.esc_html__('Setup footer settings','tutorly').'..</p>',
					'fields' => array( 
							           
	                        array(
								'id' => 'google_analytics',
								'type' => 'textarea',
								'title' => esc_html__('Google Analytics Code', 'tutorly'), 
								'sub_desc' => esc_html__('Google Analytics account', 'tutorly'),
								'desc' => esc_html__('Please enter full code with javascript tags.', 'tutorly'),
							),
	                        array(
								'id' => 'footer_sidebar',
		                        'title' => esc_html__('Widgetised Footer', 'tutorly'),
		                        'sub_desc' => esc_html__('set widgets in footer', 'tutorly'),
		                        'desc' => esc_html__('Create a Footer using Widgets.', 'tutorly'),
		                        'type' => 'button_set',
								'options' => array(
									''=>esc_html__('Disable','tutorly'),
									'1' => esc_html__('Enable','tutorly')
								),
								'std' => ''
							),
	                        array(
								'id' => 'footer_sidebar_colums',
								'type' => 'select',
								'options'=>[
									5=>esc_html__('5 columns','tutorly'),
									4=>esc_html__('4 columns','tutorly'),
									3=>esc_html__('3 columns','tutorly'),
									2=>esc_html__('2 columns','tutorly')
								],
								'title' => esc_html__('Number of Columns', 'tutorly'), 
								'sub_desc' => esc_html__('Set columns for Widgets in Footer', 'tutorly'),
								'desc' => esc_html__('This is only valid for Classic Widgets.', 'tutorly'),
							),

						 				
						)
					);

	$sections[] = array(
					'icon' => 'location',
					'title' => esc_html__('Miscellaneous', 'tutorly'),
					'desc' =>'<p class="description">'. esc_html__('Miscellaneous settings used in the theme.', 'tutorly').'</p>',
					'fields' => array(
							array(
							'id' => 'excerpt_length',
							'type' => 'text',
							'title' => esc_html__('Default Excerpt Length', 'tutorly'), 
							'sub_desc' => esc_html__('Excerpt length in number of Words.', 'tutorly'),
							'std' => '20'
							),
	                        array(
								'id' => 'error404',
								'type' => 'pages_select',
								'title' => esc_html__('Select 404 Page', 'tutorly'), 
								'sub_desc' => esc_html__('This page is shown when page not found on your site.', 'tutorly'),
								'desc' => esc_html__('User redirected to this page when page not found.', 'tutorly'),
							), 
							array(
								'id' => 'xmlrpc',
								'type' => 'button_set',
								'title' => esc_html__('Disable XMLRPC/RSD/WLWManifest', 'tutorly'), 
								'sub_desc' => esc_html__('Remove security vulnerabilities', 'tutorly'),
								'desc' => esc_html__('Removes vulnerabilities at expense of ability to login via remote apps.', 'tutorly'),
								'options' => array('' => esc_html__('No','tutorly'),1 => esc_html__('Yes','tutorly')),
								'std' => ''
							),
							array(
								'id' => 'wp_login_screen',
								'type' => 'textarea',
								'title' => esc_html__('Custom CSS for WP Login Screen', 'tutorly'), 
								'sub_desc' => esc_html__('Add custom CSS', 'tutorly'),
								'desc' => esc_html__('Custom CSS for WP Login screen.', 'tutorly'),
							),
							array(
								'id' => 'credits',
								'type' => 'text',
								'title' => esc_html__('Author & Credits', 'tutorly'), 
								'sub_desc' => esc_html__('Credits and Author of the Website', 'tutorly'),
								'desc' => esc_html__('Changes the reference to Author {VibeThemes}', 'tutorly'),
		                        'std' => 'VibeThemes'
							),
	                      )
	                    );

	global $Vibe_Options;
	return apply_filters('tutorly_option_custom_sections',$sections);
}
/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();
	global $Vibe_Options;

	$Vibe_Options = get_option(THEME_SHORT_NAME);  //Initialize tutorlyoptions
	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;

	//google api key MUST BE DEFINED IF YOU WANT TO USE GOOGLE WEBFONTS
	//$args['google_api_key'] = '***';

	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	$args['intro_text'] = '';
	//Setup custom links in the footer for share icons
	$args['share_icons']['twitter'] = array(
		'link' => 'http://twitter.com/vibethemes',
		'title' => esc_html__('Folow me on Twitter','tutorly'), 
		'img' => VIBE_OPTIONS_URL.'img/ico-twitter.png'
	);
	$args['share_icons']['facebook'] = array(
		'link' => 'http://facebook.com/vibethemes',
		'title' => esc_html__('Be our Fan on Facebook','tutorly'), 
		'img' => VIBE_OPTIONS_URL.'img/ico-facebook.png'
	);
	$args['share_icons']['rss'] = array(
		'link' => 'feed://themeforest.net/feeds/users/VibeThemes',
		'title' => esc_html__('Latest News from VibeThemes','tutorly'), 
		'img' => VIBE_OPTIONS_URL.'img/ico-rss.png'
	);

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = THEME_SHORT_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = THEME_FULL_NAME;

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = esc_html__('Vibe Options Panel v 2.0', 'tutorly');

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "tutorly_theme_options"
	$args['page_slug'] = THEME_SHORT_NAME.'_options';

	//Custom page capability - default is set to "manage_options"
	$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';
	//$args['page_parent'] = 'themes.php';
	$social_links=array();
	if(function_exists('social_sharing_links')){
	$social_links= social_sharing_links();
	foreach($social_links as $link => $value){
	    $social_links[$link]=$link;
	 }
	}


	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	$args['help_tabs'][] = array(
								'id' => 'tutorly-opts-1',
								'title' => esc_html__('Support', 'tutorly'),
								'content' => '<p>'.esc_html__('We provide support via three mediums (in priority)','tutorly').':
	                                                            <ul><li><a href="https://tutorlydocs.wpappointify.com" target="_blank">'.THEME_FULL_NAME.' VibeThemes Forums</a></li><li>'.esc_html__('Support Email: VibeThemes@gmail.com', 'tutorly').'</li><li>'.esc_html__('ThemeForest Item Comments','tutorly').'</li></ul>
	                                                            </p>',
								);
	$args['help_tabs'][] = array(
								'id' => 'tutorly-opts-2',
								'title' => esc_html__('Documentation & Links', 'tutorly'),
								'content' => '<ul><li><a href="http://tutorlythemes.com/documentation/wplms/forums/" target="_blank">'.THEME_FULL_NAME.' Support Panel</a></li>
		                                          <li><a href="http://wpappointify.com" target="_blank">'.THEME_FULL_NAME.' Theme Setup</a></li>
		                                          <li><a href="http://wpappointify.com" target="_blank">'.THEME_FULL_NAME.' Common FAQs/Issues</a></li>  
		                                          <li><a href="http://wpappointify.com" target="_blank">'.THEME_FULL_NAME.' Tips and Tricks</a></li>
		                                          <li><a href="http://wpappointify.com" target="_blank">'.THEME_FULL_NAME.' Feature Requests</a></li>    
		                                          <li><a href="http://wpappointify.com" target="_blank">'.THEME_FULL_NAME.' Update Log</a></li>    
		                                          <li><a href="#" target="_blank">'.THEME_FULL_NAME.' Video Guide</a></li>
		                                      </ul>
	                                                            ',
								);


	//Set the Help Sidebar for the options page - no sidebar by default										
	$args['help_sidebar'] = '<p>'.esc_html__('For Support/Help and Documentation open','tutorly').'<strong><a href="http://wpappointify.com/">'.THEME_FULL_NAME.' forums</a></strong>'.esc_html__('Or email us at','tutorly').' <a href="mailto:vibethemes@gmail.com">vibethemes@gmail.com</a>. </p>';




	$sections = vibe_options_get_sections();

	$tabs = array();
	

	if (function_exists('wp_get_theme')){
		$theme_data = wp_get_theme();
		$theme_uri = $theme_data->get('ThemeURI');
		$description = $theme_data->get('Description');
		$author = $theme_data->get('Author');
		$version = $theme_data->get('Version');
		$tags = $theme_data->get('Tags');
	}else{
		$theme_data = wp_get_theme(trailingslashit(get_stylesheet_directory()).'style.css');
		$theme_uri = $theme_data['URI'];
		$description = $theme_data['Description'];
		$author = $theme_data['Author'];
		$version = $theme_data['Version'];
		$tags = $theme_data['Tags'];
	}	

	$theme_info = '<div class="tutorly-opts-section-desc">';
	$theme_info .= '<p class="tutorly-opts-theme-data description theme-uri"><strong>Theme URL:</strong> <a href="'.$theme_uri.'" target="_blank">'.$theme_uri.'</a></p>';
	$theme_info .= '<p class="tutorly-opts-theme-data description theme-author"><strong>Author:</strong>'.$author.'</p>';
	$theme_info .= '<p class="tutorly-opts-theme-data description theme-version"><strong>Version:</strong> '.$version.'</p>';
	$theme_info .= '<p class="tutorly-opts-theme-data description theme-description">'.$description.'</p>';
	$theme_info .= '<p class="tutorly-opts-theme-data description theme-tags"><strong>Tags:</strong> '.implode(', ', $tags).'</p>';
	$theme_info .= '</div>';
	$tabs['theme_info'] = array(
		'icon' => 'info-sign',
		'title' => esc_html__('Theme Information', 'tutorly'),
		'content' => $theme_info
	);
	$Vibe_Options = new Vibe_Options($sections, $args, $tabs);
	wp_cache_delete('tutorly_option','settings');
	
}//function
add_action('init', 'setup_framework_options', 0);

/*
 * 
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	

}//function

/*
 * 
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){
	
	$error = false;
	$value =  'just testing';
	
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;
	
}//function


?>
